-- initialize mission parameters

numberOfBattles = 0
numberOfInfantryGroups = 0
numberOfConvoys = {blue = 0, red = 0}
numberOfFighterJets = {blue = 0, red = 0}
numberOfTransports = {blue = 3, red = 3}
numberOfHelicopterSEAD = {blue = 0, red = 0}

-- functions used by the mission

presentPositionRequested = function(playerGroupName) -- this function gets executed whenever the "copilot estimate position" menu item has been selected
	local playerName = Unit.getName(Group.getUnits(Group.getByName(playerGroupName))[1])
	HS.outUnit(playerName,'[copilot for ' .. playerName .. '] I estimate our present position to be at ' .. HS.estimatePresentPosition(playerGroupName),30)
end

playerHasBecomeActive = function(playerName) -- this function gets executed whenever a player becomes active
	local playerUnit = Unit.getByName(playerName)
	if playerUnit then
		local coa = HS.getUnitCoalition(playerName)
		HS.out(coa,playerName .. ' has become active.',10)
		local playerGroupName = Group.getName(Unit.getGroup(playerUnit))
		if playerUnit:getTypeName() == 'UH-1H' or playerUnit:getTypeName() == 'Mi-8MT' then -- radio items specific for transport choppers
			HS.addRadioItem(playerGroupName,'copilot, estimate present position',presentPositionRequested,{playerGroupName}) -- add radio item
			HS.addCheckForIncoming(playerName) -- make sure that copilot gives warning when an enemy missile is launched
			HS.addCheckForSinkRate(playerName) -- make sure that copilot gives warning when dangerously close to VRS
		end
		HS.onTakeOffDo(playerName,HS.out,{coa,playerName .. ' has taken off',10}) -- give message when unit takes off
		HS.onTouchDownDo(playerName,HS.out,{coa,playerName .. ' has landed',10}) -- give message when unit touches down
	end
end

playerHasBecomeInactive = function(playerName) -- this function gets executed whenever a player becomes inactive
	local coa = HS.getUnitCoalition(playerName)
	HS.out(coa,playerName .. ' has become inactive.',10)
	HS.removeRadioItems(playerName) -- remove all radio items for this player
end

-- end of functions

-- define sound files

HS.setIncomingAudio('incoming.wav')
HS.setRadioStaticAudio('RadioClickAfter.wav')
HS.setBeaconAudio('VHF_WarningTone.wav')
HS.setSinkRateAudio('sinkRate.wav')
HS.setHoverDirectionsAudio('up.wav','down.wav','left.wav','right.wav','forward.wav','back.wav')
HS.setCargoHookedAudio('Hooked.wav')

-- end define sound files

-- set up troops and structures at airfields

HS.initializeFARP('FARP London')
HS.initializeFARP('FARP Moscow')

HS.initializeFARP('FARP Vetka')
HS.initializeFARP('FARP Kalitka')

-- end set up troops and structures at airfields

-- initialize ground battle

-- end initialize ground battle

-- initialize air defences

-- HS.generateAirDefence('red',3,'Russian AAA Zone')
-- HS.generateAirDefence('blue',3,'US AAA Zone')

-- end initialize air defences

-- define what happens when units become active

local count

for count = 1, #mist.DBs.MEunitsByCat.helicopter do
	HS.onBecomesActiveDo(mist.DBs.MEunitsByCat.helicopter[count].unitName,playerHasBecomeActive,{mist.DBs.MEunitsByCat.helicopter[count].unitName})
	HS.onBecomesInactiveDo(mist.DBs.MEunitsByCat.helicopter[count].unitName,playerHasBecomeInactive,{mist.DBs.MEunitsByCat.helicopter[count].unitName})
end

-- end define what happens when units become active

-- initialize AI transport flights

for count = 1,numberOfTransports.blue do
	mist.scheduleFunction(HS.flyTransportMission,{'blue','Hercules Group #' .. count},timer.getTime()+mist.random(500))
end

for count = 1,numberOfTransports.red do
	mist.scheduleFunction(HS.flyTransportMission,{'red','An26 Group #' .. count},timer.getTime()+mist.random(500))
end

-- initialize AI air superiority fighters

HS.setAirBattleZone('Air Battle Zone')

-- for count = 1,numberOfFighterJets.blue do
	-- HS.flyFighterMission('blue','Tiger Group #' .. count)
-- end

-- for count = 1,numberOfFighterJets.red do
	-- HS.flyFighterMission('red','Mig Group #' .. count)
-- end

-- end initialize AI air superiority fighters

-- initialize AI helicopter SEAD flights

HS.setSEADZone({blue = 'Russian AAA Zone',red = 'US AAA Zone'})

-- for count = 1,numberOfHelicopterSEAD.blue do
	-- HS.flyHelicopterSEADMission('blue','US Helicopter SEAD Group #' .. count)
-- end

-- for count = 1,numberOfHelicopterSEAD.red do
	-- HS.flyHelicopterSEADMission('red','Russian Helicopter SEAD Group #' .. count)
-- end

-- end initialize AI helicopter SEAD flights

-- initialize truck resupply convoys

-- for count = 1,numberOfConvoys.blue do
	-- mist.scheduleFunction(HS.createNewConvoy,{'blue','Ground Battle Zone #' .. math.random(numberOfBattles)},timer.getTime()+150+mist.random(150))
-- end

-- for count = 1,numberOfConvoys.blue do
	-- mist.scheduleFunction(HS.createNewConvoy,{'red','Ground Battle Zone #' .. math.random(numberOfBattles)},timer.getTime()+150+mist.random(150))
-- end

-- end initialize truck resupply convoys

-- initialize random events where a mechanized group defined in the mission editor is spotted
